.. _links:

Links
=====

Below links relevant to Stetl.

Presentations
=============

Below several presentations on Stetl given at various events. The most recent/relevant at the top.

* `GeoPython2016 - Spatial ETL with Stetl <http://www.slideshare.net/justb4/geospatial-etl-with-stetl-geopython-2016>`_
* `5-minute intro Stetl <http://www.slideshare.net/justb4/5-minute-intro-to-setl>`_
* `FOSS4G Nottingham 2013 <http://www.slideshare.net/justb4/stetl-foss4g20131024v1>`_
* `Eurogeographics 2013 - INSPIRE Transform with Stetl: <http://www.slideshare.net/justb4/2-stetlinspiretransformv1>`_
* `Video recording of Eurogeographics 2013 Stetl pres: <https://www.youtube.com/watch?v=vjdpYBm4AaM>`_
* `Several presentations on Stetl on SlideShare <http://www.slideshare.net/justb4>`_  (search for 'Stetl')

Stetl Projects/Cases
====================

Known uses of Stetl. More detail in the chapter on :ref:`cases`.

* `NLExtract <http://nlextract.nl>`_
* `SOSPilot <http://sospilot.geonovum.nl>`_
* `Smart Emission <http://smartemission.nl>`_
* `INSPIRE FOSS Project (Archived) <https://github.com/justb4/inspire-foss>`_

Tools
=====

Tools/components used by/with Stetl.

* `GDAL/OGR <http://gdal.org>`_
* `lxml <http://lxml.de>`_
* `deegree WMS/WFS <http://www.deegree.org>`_
* `PostGIS/PostgreSQL <http://http://postgis.org/>`_
* `Jinja2 <http://jinja.pocoo.org/>`_

Other
=====

* `More Geospatial Python projects, <https://github.com/geopython>`_
* `INSPIRE, <http://inspire.ec.europa.eu/>`_
